[libvirt] [test-API 01/10] Create new dir 'conf' and move conf files into it

Osier Yang jyang at redhat.com
Wed Apr 18 05:49:01 UTC 2012


---
 env.cfg => conf/env.cfg                            |    0
 kickstart.cfg => conf/kickstart.cfg                |    0
 exception.py                                       |    2 +-
 generator.py                                       |    2 +-
 parser.py                                          |    4 ++--
 repos/domain/install_image.py                      |    2 +-
 repos/domain/install_linux_cdrom.py                |    2 +-
 repos/domain/install_linux_check.py                |    2 +-
 repos/domain/install_linux_net.py                  |    4 ++--
 repos/domain/install_windows_cdrom.py              |    6 +++---
 .../multiple_thread_block_on_domain_create.py      |    2 +-
 11 files changed, 13 insertions(+), 13 deletions(-)
 rename env.cfg => conf/env.cfg (100%)
 rename kickstart.cfg => conf/kickstart.cfg (100%)

diff --git a/env.cfg b/conf/env.cfg
similarity index 100%
rename from env.cfg
rename to conf/env.cfg
diff --git a/kickstart.cfg b/conf/kickstart.cfg
similarity index 100%
rename from kickstart.cfg
rename to conf/kickstart.cfg
diff --git a/exception.py b/exception.py
index 3625dab..190fd9f 100644
--- a/exception.py
+++ b/exception.py
@@ -76,7 +76,7 @@ class CaseConfigfileError(LibvirtException):
 
 class MissingVariable(LibvirtException):
     code = 210
-    message = "Variables missing from env.cfg [variables] section"
+    message = "Variables missing from conf/env.cfg [variables] section"
 
 class TestError(LibvirtException):
     code = 211
diff --git a/generator.py b/generator.py
index 53febde..fc4fc76 100644
--- a/generator.py
+++ b/generator.py
@@ -59,7 +59,7 @@ class FuncGen(object):
         # Save case information to a file in a format
         self.__case_info_save(activity, testrunid)
 
-        self.env = env_parser.Envparser("env.cfg")
+        self.env = env_parser.Envparser("conf/env.cfg")
 
         mapper_obj = mapper.Mapper(activity)
         pkg_casename_func = mapper_obj.module_casename_func_map()
diff --git a/parser.py b/parser.py
index b0bad3b..07d1498 100644
--- a/parser.py
+++ b/parser.py
@@ -35,7 +35,7 @@ class CaseFileParser(object):
         self.missing_variables = []
         self.debug = debug
         self.casefile = casefile
-        self.env = env_parser.Envparser("env.cfg")
+        self.env = env_parser.Envparser("conf/env.cfg")
         self.loop_finish = False
         self.loop_start = 0
         self.loop_end = 0
@@ -210,7 +210,7 @@ class CaseFileParser(object):
                 tripped_valuelist = self.variables_lookup(tripped_valuelist)
                 if len(self.missing_variables) != 0:
                     raise exception.MissingVariable(
-                    "The variables %s referenced in %s could not be found in env.cfg" %
+                    "The variables %s referenced in %s could not be found in conf/env.cfg" %
                         (self.missing_variables, self.casefile))
 
                 tripped_valuename = tripped_valuelist[0]
diff --git a/repos/domain/install_image.py b/repos/domain/install_image.py
index 32cc7af..0d2d7e2 100644
--- a/repos/domain/install_image.py
+++ b/repos/domain/install_image.py
@@ -60,7 +60,7 @@ def install_image(params):
     logger.info("the path of directory of disk images located on is %s" %
                  imgfullpath)
 
-    envfile = os.path.join(HOME_PATH, 'env.cfg')
+    envfile = os.path.join(HOME_PATH, 'conf/env.cfg')
     logger.info("the environment file is %s" % envfile)
 
     envparser = env_parser.Envparser(envfile)
diff --git a/repos/domain/install_linux_cdrom.py b/repos/domain/install_linux_cdrom.py
index 07a8307..1805db2 100644
--- a/repos/domain/install_linux_cdrom.py
+++ b/repos/domain/install_linux_cdrom.py
@@ -223,7 +223,7 @@ def install_linux_cdrom(params):
         logger.info("creating disk images file is successful.")
 
     logger.info("get system environment information")
-    envfile = os.path.join(HOME_PATH, 'env.cfg')
+    envfile = os.path.join(HOME_PATH, 'conf/env.cfg')
     logger.info("the environment file is %s" % envfile)
 
     envparser = env_parser.Envparser(envfile)
diff --git a/repos/domain/install_linux_check.py b/repos/domain/install_linux_check.py
index 1c27fc1..2a1351d 100644
--- a/repos/domain/install_linux_check.py
+++ b/repos/domain/install_linux_check.py
@@ -150,7 +150,7 @@ def install_linux_check(params):
     # Check app works fine in guest, such as: wget
     logger.info("check point5: check app works fine in guest, such as: wget")
     logger.info("get system environment information")
-    envfile = os.path.join(HOME_PATH, 'env.cfg')
+    envfile = os.path.join(HOME_PATH, 'conf/env.cfg')
     logger.info("the environment file is %s" % envfile)
 
     envparser = env_parser.Envparser(envfile)
diff --git a/repos/regression/multiple_thread_block_on_domain_create.py b/repos/regression/multiple_thread_block_on_domain_create.py
index 38030c2..53332ab 100644
--- a/repos/regression/multiple_thread_block_on_domain_create.py
+++ b/repos/regression/multiple_thread_block_on_domain_create.py
@@ -116,7 +116,7 @@ def multiple_thread_block_on_domain_create(params):
     logger.info("the type of hypervisor is %s" % hypervisor)
     logger.debug("the uri to connect is %s" % uri)
 
-    envfile = os.path.join(homepath, 'env.cfg')
+    envfile = os.path.join(homepath, 'conf/env.cfg')
     envparser = env_parser.Envpaser(envfile)
     ostree = envparser.get_value("guest", guestos + "_" + arch)
     ks = envparser.get_value("guest", guestos + "_" + arch +
diff --git a/repos/domain/install_linux_net.py b/repos/domain/install_linux_net.py
index a5fca06..ae5a063 100644
--- a/repos/domain/install_linux_net.py
+++ b/repos/domain/install_linux_net.py
@@ -188,13 +188,13 @@ def install_linux_net(params):
 
 
     logger.info("get system environment information")
-    envfile = os.path.join(HOME_PATH, 'env.cfg')
+    envfile = os.path.join(HOME_PATH, 'conf/env.cfg')
     logger.info("the environment file is %s" % envfile)
 
     envparser = env_parser.Envparser(envfile)
 
     # Get http, ftp or nfs url based on guest os, arch
     # and installation method from env.cfg
 
     if installmethod == 'http':
         ks = envparser.get_value("guest", guestos + "_" + guestarch +
@@ -188,13 +188,13 @@ def install_linux_net(params):
 
     # Get http, ftp or nfs url based on guest os, arch
-    # and installation method from env.cfg
+    # and installation method from conf/env.cfg
 
     if installmethod == 'http':
diff --git a/repos/domain/install_windows_cdrom.py b/repos/domain/install_windows_cdrom.py
index aaff47d..a4c10e2 100644
--- a/repos/domain/install_windows_cdrom.py
+++ b/repos/domain/install_windows_cdrom.py
@@ -256,10 +256,10 @@ def install_windows_cdrom(params):
         logger.info("creating disk images file is successful.")
 
     logger.info("get system environment information")
-    envfile = os.path.join(HOME_PATH, 'env.cfg')
+    envfile = os.path.join(HOME_PATH, 'conf/env.cfg')
     logger.info("the environment file is %s" % envfile)
 
     # Get iso file based on guest os and arch from env.cfg
     envparser = env_parser.Envparser(envfile)
     iso_file = envparser.get_value("guest", guestos + '_' + guestarch)
     cdkey = envparser.get_value("guest", "%s_%s_key" % (guestos, guestarch))
@@ -427,7 +427,7 @@ def install_windows_cdrom_clean(params):
     guestos = params.get('guestos')
     guestarch = params.get('guestarch')
 
-    envfile = os.path.join(HOME_PATH, 'env.cfg')
+    envfile = os.path.join(HOME_PATH, 'conf/env.cfg')
     envparser = env_parser.Envparser(envfile)
     iso_file = envparser.get_value("guest", guestos + '_' + guestarch)
 
@@ -256,10 +256,10 @@ def install_windows_cdrom(params):
     logger.info("the environment file is %s" % envfile)
 
-    # Get iso file based on guest os and arch from env.cfg
+    # Get iso file based on guest os and arch from conf/env.cfg
     envparser = env_parser.Envparser(envfile)
     iso_file = envparser.get_value("guest", guestos + '_' + guestarch)
-- 
1.7.7.3




More information about the libvir-list mailing list